Index: uspace/srv/hid/input/include/mouse.h
===================================================================
--- uspace/srv/hid/input/include/mouse.h	(revision 336d2f520e09eb22615e1ef5eed791543683ae14)
+++ uspace/srv/hid/input/include/mouse.h	(revision 6d605e69652806366168cf5466d2498cf2f28dbf)
@@ -39,4 +39,5 @@
 
 #include <adt/list.h>
+#include <ipc/loc.h>
 
 struct mouse_port_ops;
@@ -47,6 +48,6 @@
 	link_t mouse_devs;
 	
-	/** Path to the device (only for mouseev devices) */
-	const char *dev_path;
+	/** Service ID (only for mousedev devices) */
+	service_id_t service_id;
 	
 	/** Port ops */

Index: uspace/srv/hid/input/include/kbd.h
===================================================================
--- uspace/srv/hid/input/include/kbd.h	(revision 336d2f520e09eb22615e1ef5eed791543683ae14)
+++ uspace/srv/hid/input/include/kbd.h	(revision 6d605e69652806366168cf5466d2498cf2f28dbf)
@@ -40,4 +40,5 @@
 
 #include <adt/list.h>
+#include <ipc/loc.h>
 
 struct kbd_port_ops;
@@ -49,6 +50,6 @@
 	link_t kbd_devs;
 
-	/** Path to the device (only for kbdev devices) */
-	const char *dev_path;
+	/** Service ID (only for kbdev devices) */
+	service_id_t service_id;
 
 	/** Port ops */